breed [peds ped]
breed [robots robot]

globals [time
  mean-speed
  stddev-speed
  flow-cum
  PP
  PB
  PC
  PA
  velocity
  cum-vel
  vel-reduction
  acceleration
  cum-acc
  ]

peds-own [speedx speedy state]
robots-own [speedx speedy speedx-last-tick speedy-last-tick]

to setup
  clear-all reset-ticks if cycle?[set Nb-peds 5 set dt .05]
  set-agents
  set-robots
  ask patch goal_xcor goal_ycor  [set pcolor green]               ;; create the goal patch
  ask patches with [pxcor = -5 or pxcor = 5] [set pcolor white]   ;; create corridor
  ask robots [pen-down]
end

to set-agents
  repeat round (p * nb-peds) [c-ped 0 min-pycor + 4 0]
  repeat round (p * nb-peds) [c-ped 0 max-pycor - 4 1]
end

to set-robots
  create-robots 1 [setxy robot_xcor robot_ycor set color grey set size 1]
end

to c-ped  [x y k]
  if k = 0 [ask one-of patches with  [pycor > -18 and pycor < -2 and pxcor < 4 and pxcor > -4 and not any? peds-here] [set x pxcor set y pycor] ;;blue goes up
  create-peds 1 [set shape "circle 2"
                 set color cyan
                 set xcor x + random-normal 0 .2
                 set ycor y + random-normal 0 .2
                 set size 1]]
  if k = 1 [ask one-of patches with  [pycor < 18 and pycor > 2 and pxcor < 4 and pxcor > -4 and not any? peds-here] [set x pxcor set y pycor]  ;;orange goes down
  create-peds 1 [set shape "circle 2"
                 set xcor x + random-normal 0 .2
                 set ycor y + random-normal 0 .2
                 set state 2
                 set color orange
                 set size 1]]
  if k = -1 [create-peds 1 [set color white
                            set state -1 set
                            shape "box"
                            set xcor x
                            set ycor y
                            set size 1]]

end

to Create [k] ; create obstacle using mouse click
  if timer > .2 and mouse-down?[reset-timer c-ped mouse-xcor mouse-ycor k] display
end

to Delete [k] ; delete obstacle
  if timer > .2 and mouse-down?
  [reset-timer create-turtles 1 [set color black setxy mouse-xcor mouse-ycor ask peds with [state = k] in-radius .5 with-min [distance myself] [die]]
    ask turtles with [color = black][die]] display
end

to plot!
  set-current-plot "Speed"
  set-current-plot-pen "Mean"
  plotxy time mean-speed / ticks
  set-current-plot-pen "Stddev"
  plotxy time stddev-speed / ticks
  set-current-plot "Mean flow" set-plot-y-range 0 2
  set-current-plot-pen "Spatial"
  plotxy time (mean-speed / ticks * Nb-peds / world-width / world-height)
  set-current-plot-pen "Temporal"
  plotxy time flow-cum / time / world-height

  ;; Added Plots
  set-current-plot "PC"
  plotxy time PC
  set-current-plot "PP"
  plotxy time PP
  set-current-plot "PA"
  plotxy time PA
  set-current-plot "PB"
  plotxy time PB
  set-current-plot "Robot Velocity"
  ;set-current-plot-pen "Actual"
  plotxy time velocity
  ;set-current-plot-pen "Average"
  ;plotxy time cum-vel / time
  set-current-plot "Robot Velocity reduction"
  plotxy time vel-reduction
  set-current-plot "Robot Acceleration"
  ;set-current-plot-pen "Actual"
  plotxy time acceleration
  ;set-current-plot-pen "Average"
  ;plotxy time cum-acc / time


end


to move
  ;; Stop if goal is reached
  ask robots [if pcolor = green [user-message (word "The robot reached the goal")]]

  ;; TIME
  set time precision (time + dt) 5 tick-advance 1

  ;; ROBOT MOVEMENT
  ask robots [
      ;; for repulsion force
      let repx 0
      let repy 0

      ;; for velocity reduction
      let velr 0

      ;; for F facepose
      let fposx 0
      let fposy 0

      set heading towardsxy goal_xcor goal_ycor
      let hd hd1
      let h hd1
      if not (speedx * speedy = 0)
      [set h atan speedx speedy]

      ask peds in-radius (2 * D)
      [
        set repx repx +  A * exp((1 - distance myself) / D) * sin(towards myself) * (1 - cos(towards myself - h))
        set repy repy +  A * exp((1 - distance myself) / D) * cos(towards myself) * (1 - cos(towards myself - h))

        ;; for PB
        if sqrt ( speedx ^ 2 + speedy ^ 2 ) < 0.01 [if time > 0.05 [set PB PB + 1]]
      ]

      ;; F facepose addition
      ask peds in-cone (2 * D) lambda [

        set fposx fposx + FS * exp ((1 - distance myself) / D) * speedx * (lambda + (lambda + 1) * ( 1 + cos(towards myself)))
        set fposy fposy + FS * exp ((1 - distance myself) / D) * speedy * (lambda + (lambda + 1) * ( 1 + cos(towards myself)))
      ]
      ask patches with [pcolor = white] in-radius (2 * D)
      [
        set repx repx + A * exp((1 - distance myself) / D) * sin(towards myself) * (1 - cos(towards myself - h))
        set repy repy + A * exp((1 - distance myself) / D) * cos(towards myself) * (1 - cos(towards myself - h))

        ;; velocity reduction with a minimum velocity of 0.5 m/s because of cost function
        set velr 1 / distance one-of robots
        ;; for velocity reduction plot
        set vel-reduction velr

      ]

      ;; use minimum velocity of 0.5 m/s if velocity reduction is too large
      if velr > speedx [set velr V0 - 0.5]
      if velr > speedy   [set velr V0 - 0.5]


      set speedx-last-tick speedx
      set speedy-last-tick speedy

      set speedx speedx  + dt * (repx + fposx + (V0 * sin(heading) - speedx) / Tr - velr)
      set speedy speedy  + dt * (repy + fposy + (V0 * cos(heading) - speedy) / Tr - velr)

      let dvx speedx - speedx-last-tick
      let dvy speedy - speedy-last-tick
      let ax dvx / dt
      let ay dvy / dt
      set acceleration sqrt(ax ^ 2 + ay ^ 2)

      ;; restrict velocities in case forces become to big
      if velocity > V0 [set speedx speedx / velocity set speedy speedy / velocity]

      ;; for velocity plot
      set velocity sqrt((speedx) ^ 2 + (speedy) ^ 2)

      ;set cum-vel cum-vel + velocity
      ;set cum-acc cum-acc + acceleration



      set xcor xcor + speedx * dt
      set ycor ycor + speedy * dt

      if ycor > 20 [set ycor 20]
      if ycor < -20 [set ycor -20]
      if xcor < -5 [set xcor -4.5]
      if xcor > 5 [set xcor 4.5]
  ]

  ;; HUMAN MOVEMENT
  ask peds with [state > -1]
    [

      ;; Data for plots
      ask robots in-radius 1 [set PC PC + sqrt(speedx ^ 2 + speedy ^ 2) * 10
      ]
      ask robots in-radius 1.2 [set PP PP + sqrt(speedx ^ 2 + speedy ^ 2) / distance myself
                                if acceleration > 0.68 [set PA PA + (a - 0.68)]
                               ]



      let fposx 0
      let fposy 0
      let repx 0
      let repy 0
      let hd hd1
      if state = 2 [set hd hd2]
      let h hd1
      if not (speedx * speedy = 0)
      [set h atan speedx speedy]
      ask peds in-radius (2 * D) with [not (self = myself)] ; self is me. myself is the agent who is asking me to do whatever I'm doing now.
      [
        set repx repx + A * exp((1 - distance myself) / D) * sin(towards myself) * (1 - cos(towards myself - h))
        set repy repy + A * exp((1 - distance myself) / D) * cos(towards myself) * (1 - cos(towards myself - h))
      ]
      ask robots in-radius (2 * D)
      [
        set repx repx + amp * A * exp((1 - distance myself) / D) * sin(towards myself) * (1 - cos(towards myself - h))
        set repy repy + amp * A * exp((1 - distance myself) / D) * cos(towards myself) * (1 - cos(towards myself - h))
      ]

      ;; F facepose addition
      ask robots in-cone (2 * D) lambda [

        set fposx fposx + FS * exp ((1 - distance myself) / D) * speedx * (lambda + (lambda + 1) * ( 1 + cos(towards myself - h)))
        set fposy fposy + FS * exp ((1 - distance myself) / D) * speedy * (lambda + (lambda + 1) * ( 1 + cos(towards myself - h)))
      ]
      ask patches with [pcolor = white] in-radius (2 * D)
      [
        set repx repx + A * exp((1 - distance myself) / D) * sin(towards myself) * (1 - cos(towards myself - h))
        set repy repy + A * exp((1 - distance myself) / D) * cos(towards myself) * (1 - cos(towards myself - h))
      ]
      set speedx speedx + dt * (repx + fposx + (V0 * sin hd - speedx) / Tr)
      set speedy speedy + dt * (repy + fposy + (V0 * cos hd - speedy) / Tr)


      ifelse ycor > 19 and time > 1 and state = 0 and speedy * dt < 0.5
      [set ycor -19]
      [set xcor xcor + speedx * dt
      set ycor ycor + speedy * dt]
      ifelse ycor < -19 and time > 1 and state = 2 and speedy * dt < 0.5
      [set ycor 19]
      [set xcor xcor + speedx * dt
      set ycor ycor + speedy * dt]
      if xcor < -4.5 [set xcor -4.5]
      if xcor > 4.5 [set xcor 4.5]
  ]


;; Standard plots
  set mean-speed mean-speed + mean [sqrt(speedx ^ 2 + speedy ^ 2)] of peds with [state > -1]
  set stddev-speed stddev-speed + sqrt(variance [sqrt(speedx ^ 2 + speedy ^ 2)] of peds with [state > -1])

  ask peds with[(xcor > 0 and xcor - speedx * dt <= 0)
    or (xcor < 0 and xcor - speedx * dt >= 0)
    or (ycor > 0 and ycor - speedy * dt <= 0)
    or (ycor < 0 and ycor - speedy * dt >= 0)]
    [set flow-cum flow-cum + 1]
  plot!

  if cycle? and time > 500[
      set-current-plot "Fundamental diagram" plotxy (Nb-peds / world-width / world-height) (Nb-peds / world-width / world-height * mean-speed / ticks)
      set-current-plot "Speed stddev" plotxy (Nb-peds / world-width / world-height) (stddev-speed / ticks)
      ask peds [die] set Nb-peds Nb-peds + 20
      set time 0 set mean-speed 0 set stddev-speed 0  set flow-cum 0
      set-current-plot "Speed" clear-plot set-current-plot "Mean flow" clear-plot reset-ticks
      ifelse Nb-peds > 200 [stop][set-agents]]
end
@#$#@#$#@
GRAPHICS-WINDOW
1379
13
2412
1047
-1
-1
25.0
1
10
1
1
1
0
1
0
1
-20
20
-20
20
0
0
1
Ticks
30.0

SLIDER
221
77
324
110
Nb-peds
Nb-peds
0
200
50.0
1
1
NIL
HORIZONTAL

BUTTON
160
94
215
128
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
160
131
215
164
NIL
Move
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
707
182
867
302
Mean flow
Time
Flow
0.0
0.0
0.0
0.0
true
true
"" ""
PENS
"Spatial" 1.0 0 -11053225 true "" ""
"Temporal" 1.0 0 -11881837 true "" ""

PLOT
706
59
866
179
Speed
Time
Speed
0.0
0.0
0.0
0.0
true
true
"" ""
PENS
"Mean" 1.0 0 -11053225 true "" ""
"Stddev" 1.0 0 -11881837 true "" ""

SLIDER
329
76
421
109
V0
V0
0
5
1.4
0.1
1
NIL
HORIZONTAL

MONITOR
177
20
235
65
Time
time
17
1
11

MONITOR
300
20
370
65
Mean speed
mean [sqrt(speedx ^ 2 + speedy ^ 2)] of peds with [state > -1]
5
1
11

MONITOR
373
20
450
65
Speed stddev
stddev-speed / ticks
5
1
11

MONITOR
238
20
296
65
Density
Nb-peds / world-width / world-height
5
1
11

MONITOR
453
20
514
65
Flow
flow-cum / time / world-height
5
1
11

PLOT
866
60
1026
180
Fundamental diagram
Density
Flow
0.0
0.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -11053225 true "" ""

PLOT
867
180
1027
300
Speed stddev
Density
Stddev
0.0
0.0
0.0
0.7
true
false
"" ""
PENS
"default" 1.0 0 -11053225 true "" ""

SWITCH
425
186
528
219
cycle?
cycle?
1
1
-1000

SLIDER
221
113
324
146
dt
dt
0
1
0.05
.01
1
NIL
HORIZONTAL

SLIDER
329
185
421
218
D
D
0.1
5
0.9
.1
1
NIL
HORIZONTAL

BUTTON
160
167
215
200
NIL
Move
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
329
148
421
181
A
A
0
5
1.5
.1
1
NIL
HORIZONTAL

SLIDER
424
113
529
146
hd1
hd1
0
360
0.0
5
1
degree
HORIZONTAL

SLIDER
329
112
421
145
Tr
Tr
.1
2
0.4
.1
1
NIL
HORIZONTAL

SLIDER
424
148
529
181
hd2
hd2
0
360
180.0
5
1
degree
HORIZONTAL

SLIDER
424
77
529
110
p
p
0
1
0.5
.05
1
NIL
HORIZONTAL

BUTTON
221
149
324
182
Create-obstacle
create -1
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
221
184
324
217
Delete-obstacle
delete -1
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
545
68
700
128
robot_xcor
0.0
1
0
Number

INPUTBOX
543
130
698
190
robot_ycor
-18.0
1
0
Number

INPUTBOX
543
191
698
251
goal_xcor
0.0
1
0
Number

INPUTBOX
542
250
697
310
goal_ycor
18.0
1
0
Number

PLOT
12
332
295
543
PP
Time (s)
Personal Space Score
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
15
542
294
782
PC
Time (s)
Human Collision Score
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
295
333
575
541
PB
Time (s)
Humans Blocked Score
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
294
540
573
779
PA
Time (s)
Acceleration Score
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
546
25
718
58
amp
amp
1
5
1.0
0.01
1
NIL
HORIZONTAL

PLOT
573
542
927
779
Robot Velocity
Time (s)
Velocity (m/s)
0.0
10.0
0.0
1.5
true
false
"" ""
PENS
"Actual" 1.0 0 -16777216 true "" ""

SLIDER
218
229
390
262
FS
FS
0
3
1.51
0.01
1
NIL
HORIZONTAL

SLIDER
219
276
391
309
lambda
lambda
0
1
0.6
0.01
1
NIL
HORIZONTAL

PLOT
574
332
923
541
Robot Velocity Reduction
Time (s)
Velocity Reduction (m/s)
0.0
10.0
0.0
2.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
930
545
1268
781
Robot Acceleration
NIL
NIL
0.0
10.0
0.0
5.0
true
false
"" ""
PENS
"Actual" 1.0 0 -16777216 true "" ""

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
